==> vue-checkbox-button-2.8.0.tgz: package/lib/index.js <==
function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}
import { defineComponent, $prefix, $props, $setup } from "@dftvue2-opentiny/vue-common";
import PcTemplate from "./pc.js";
import "@dftvue2-opentiny/vue-theme/checkbox-button/index.css";
var template = function template2(mode) {
  return PcTemplate;
};
var $constants = {
  CHECKBOX_GROUP: "CheckboxGroup"
};
var CheckboxButton = defineComponent({
  name: $prefix + "CheckboxButton",
  props: _extends({}, $props, {
    _constants: {
      type: Object,
      default: function _default() {
        return $constants;
      }
    },
    modelValue: {},
    label: {},
    disabled: Boolean,
    checked: Boolean,
    name: String,
    trueLabel: [String, Number],
    falseLabel: [String, Number],
    text: String,
    events: {
      type: Object,
      default: function _default2() {
        return {};
      }
    }
  }),
  setup: function setup(props, context) {
    return $setup({
      props,
      context,
      template
    });
  }
});
var version = "2.8.0";
CheckboxButton.model = {
  prop: "modelValue",
  event: "update:modelValue"
};
CheckboxButton.install = function(Vue) {
  Vue.component(CheckboxButton.name, CheckboxButton);
};
CheckboxButton.version = version;
export {
  CheckboxButton as default
};

==> vue-checkbox-button-2.21.0.tgz: package/lib/index.js <==
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
import { defineComponent, $prefix, $props, $setup } from "@opentinyvue/vue-common";
import PcTemplate from "./pc.js";
import "@opentinyvue/vue-theme/checkbox-button/index.css";
var template = function template2(mode) {
  var _process$env;
  typeof process === "object" ? (_process$env = process.env) == null ? void 0 : _process$env.TINY_MODE : null;
  return PcTemplate;
};
var $constants = {
  CHECKBOX_GROUP: "CheckboxGroup"
};
var CheckboxButton = defineComponent({
  name: $prefix + "CheckboxButton",
  props: _extends({}, $props, {
    _constants: {
      type: Object,
      default: function _default() {
        return $constants;
      }
    },
    modelValue: {},
    label: {},
    disabled: Boolean,
    checked: Boolean,
    name: String,
    trueLabel: [String, Number],
    falseLabel: [String, Number],
    text: String,
    events: {
      type: Object,
      default: function _default2() {
        return {};
      }
    },
    tabindex: {
      type: String,
      default: "0"
    }
  }),
  setup: function setup(props, context) {
    return $setup({
      props,
      context,
      template
    });
  }
});
var version = "2.21.0";
CheckboxButton.model = {
  prop: "modelValue",
  event: "update:modelValue"
};
CheckboxButton.install = function(Vue) {
  Vue.component(CheckboxButton.name, CheckboxButton);
};
CheckboxButton.version = version;
export {
  CheckboxButton as default
};
